@@ -140,7 +140,7 @@ class ArrivalNode(Node):
                     else:
                         fwds[k] = v
             else:
-                raise UsageError("Path '%s' finished with non-zero return "
+                raise UsageError("Path '%s' returns with non-zero "
                                 "code at '%s' with forward of '%s'." % (
                                 str(edge), str(self), str(afwd)))
         return fwds
@@ -271,12 +271,14 @@ class Group(MicroappObject, GroupArgParser, EntryNode, ExitNode):
             child_perform, args, kwargs = proxy.pack_launch(
                                             dep.edge_forward(edge), edge, arr)
 
-            self.logger.debug("edge %d is launched" % edge._eid)
-
             # async launch process
-            # TODO: evaluate using callbacks
+            self.logger.debug("edge %d runs on a new process: (%s, %s, %s)." %
+                    (edge._eid, str(child_perform), str(args), str(kwargs)))
+
             async_res = self._procpool.apply_async(child_perform, args, kwargs)
 
+            self.logger.debug("edge %d is async-launched." % edge._eid)
+
         return async_res
 
     def _fini_multiproc(self):
@@ -409,7 +411,7 @@ class Group(MicroappObject, GroupArgParser, EntryNode, ExitNode):
                     if finished:
 
                         arrival, edge, out, fwd = finished
-                        self.logger.debug("finished edge: %d" % edge._eid)
+                        self.logger.debug("edge %d is finished." % edge._eid)
 
                         just_arrived.append(arrival)
 
@@ -486,7 +488,7 @@ class Group(MicroappObject, GroupArgParser, EntryNode, ExitNode):
                 else:
                     raise InternalError("assert check argument is not ArgType")
 
-        self.logger.debug("Group '%s' finished." % self._name_)
+        self.logger.debug("Group '%s' ran." % self._name_)
 
         return 0, grp_fwds
 
